%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This file calculates the lens parameters of a Cooke Triplet as described
% in Chapter 12, Handbook of Optical Design, 2nd Ed. by Daniel Malacara
%
% The input parameters are 
% user_ip1 : Focal length
% user_ip2 : Value of Phi
% user_ip3 : Index of the selected root
%
% Outputs - 
% 1. Individual lens powers, focal lengths
% 2. Lens seperations
%
% Copyright (c) 2010, Harsha U.B.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
close all;
clear all;
clc;

% Constants
user_ip1 = input('Focal lenght of system in mm : ');
FocalLength = user_ip1;           % in mm
P = 1/FocalLength;

V1 = 57.440791;             % Abbe number of PMMA
V2 = 29.909185;             % Abbe number of PolyCarbonate

user_ip2 = input('\nInput the value of Phi as a percentage of P (0-1) : ');
Phi_value = user_ip2*P;                % >50% of P, since it involves negative element
syms Phi;
syms yr complex;

% Coefficient variables
B0 = Phi*((V1/V2)+2)-P;

B1 = P*(yr-(V1/V2))-2*Phi*(1+yr);

B2 = P+Phi*yr;

% Declare coefficient variables as Sym variables
% syms B0 B1 B2;

% Equation to solve
f1 = B2*yr^2 + B1*yr + B0;

f2 = subs(f1, Phi, Phi_value);        % >50% of P, since it involves negative element
disp(f2);

X = double(solve(f2));
disp(X);

% Select the value of y2/y1 ratio
user_ip3 = input('Input the index of the root value : ');
y2y1 = X(user_ip3);

% Calculate the power of the three elements for a given Phi_value
P2 = P/(1-((V1/V2)*y2y1));
P3 = (P-Phi)^2/(y2y1*P-Phi);
P1 = Phi-y2y1*P2;

% Display the Powers of three lenses.
fprintf('\nPower of lenses\n');
fprintf('P1 : %+1.4f\n', double(subs(P1, Phi, Phi_value)));
fprintf('P2 : %+1.4f\n', P2);
fprintf('P3 : %+1.4f\n', double(subs(P3, Phi, Phi_value)));

% Focal lengths of the 3 elements are
fprintf('\nFocal lengths\n');
fprintf('F1 : %+2.2f\n', double(subs(P1, Phi, Phi_value))^-1);
fprintf('F2 : %+2.2f\n', P2^-1);
fprintf('F3 : %+2.2f\n', double(subs(P3, Phi, Phi_value))^-1);

% Lens seperations
d1 = (1-y2y1)/double(subs(P1, Phi, Phi_value));    % First lens seperation
d2 = (1-y2y1)/(P-Phi_value);                       % Second lens seperation

% Display lens seperations
fprintf('\nLens seperations\n');
fprintf('distance between lens 1 and lens 2 - d1 : %1.2f\n', d1);
fprintf('distance between lens 2 and lens 3 - d2 : %1.2f\n', d2);

